.. model_info:

=================
Model Information
=================

This section provides background information about the pyDeltaRCM model itself.
What are the model variables and parameters?
What do they mean?
How does the model simulate hydrodynamics?
How is morphodynamics handled?
All of these questions and more are answered here!

.. toctree::
   :maxdepth: 1

   yamlparameters
   modeltime
   hydrodynamics
   morphodynamics
   outputfile
